==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/DataLegendStylingRowEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendStylingRowEventArgsDescription } from "./DataLegendStylingRowEventArgsDescription";
/**
 * @hidden
 */
var DataLegendStylingRowEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DataLegendStylingRowEventArgsDescriptionMetadata, _super);
    function DataLegendStylingRowEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataLegendStylingRowEventArgsDescriptionMetadata.b = function (a) {
        if (DataLegendStylingRowEventArgsDescriptionMetadata.a == null) {
            DataLegendStylingRowEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataLegendStylingRowEventArgsDescriptionMetadata.c(DataLegendStylingRowEventArgsDescriptionMetadata.a);
        }
        if (a.g(DataLegendStylingRowEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(DataLegendStylingRowEventArgsDescriptionMetadata.a);
    };
    DataLegendStylingRowEventArgsDescriptionMetadata.c = function (a) {
        a.item("BadgeShape", "ExportedType:string:LegendItemBadgeShape");
        a.item("BadgeShape@names", "Automatic;Circle;Line;Square;Marker;Bar;Column;Hidden");
        a.item("IsBadgeVisible", "Boolean");
        a.item("IsRowVisible", "Boolean");
        a.item("SeriesIndex", "Number:int");
        a.item("SeriesTitle", "String");
        a.item("TitleText", "String");
        a.item("TitleTextColor", "Brush");
    };
    DataLegendStylingRowEventArgsDescriptionMetadata.d = function (a) {
        DataLegendStylingRowEventArgsDescriptionMetadata.b(a);
        a.u("DataLegendStylingRowEventArgs", function () { return new DataLegendStylingRowEventArgsDescription(); });
        a.t("DataLegendStylingRowEventArgs", DataLegendStylingRowEventArgsDescriptionMetadata.a);
    };
    DataLegendStylingRowEventArgsDescriptionMetadata.$t = markType(DataLegendStylingRowEventArgsDescriptionMetadata, 'DataLegendStylingRowEventArgsDescriptionMetadata');
    DataLegendStylingRowEventArgsDescriptionMetadata.a = null;
    return DataLegendStylingRowEventArgsDescriptionMetadata;
}(Base));
export { DataLegendStylingRowEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/DataLegendStylingRowEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendStylingRowEventArgsDescription } from "./DataLegendStylingRowEventArgsDescription";
/**
 * @hidden
 */
var DataLegendStylingRowEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DataLegendStylingRowEventArgsDescriptionMetadata, _super);
    function DataLegendStylingRowEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataLegendStylingRowEventArgsDescriptionMetadata.b = function (a) {
        if (DataLegendStylingRowEventArgsDescriptionMetadata.a == null) {
            DataLegendStylingRowEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataLegendStylingRowEventArgsDescriptionMetadata.c(DataLegendStylingRowEventArgsDescriptionMetadata.a);
        }
        if (a.j(DataLegendStylingRowEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(DataLegendStylingRowEventArgsDescriptionMetadata.a);
    };
    DataLegendStylingRowEventArgsDescriptionMetadata.c = function (a) {
        a.item("BadgeShape", "ExportedType:string:LegendItemBadgeShape");
        a.item("BadgeShape@names", "Automatic;Circle;Line;Square;Marker;Bar;Column;Hidden");
        a.item("IsBadgeVisible", "Boolean");
        a.item("IsRowVisible", "Boolean");
        a.item("SeriesIndex", "Number:int");
        a.item("SeriesTitle", "String");
        a.item("TitleText", "String");
        a.item("TitleTextColor", "Brush");
    };
    DataLegendStylingRowEventArgsDescriptionMetadata.d = function (a) {
        DataLegendStylingRowEventArgsDescriptionMetadata.b(a);
        a.aa("DataLegendStylingRowEventArgs", function () { return new DataLegendStylingRowEventArgsDescription(); });
        a.z("DataLegendStylingRowEventArgs", DataLegendStylingRowEventArgsDescriptionMetadata.a);
    };
    DataLegendStylingRowEventArgsDescriptionMetadata.$t = markType(DataLegendStylingRowEventArgsDescriptionMetadata, 'DataLegendStylingRowEventArgsDescriptionMetadata');
    DataLegendStylingRowEventArgsDescriptionMetadata.a = null;
    return DataLegendStylingRowEventArgsDescriptionMetadata;
}(Base));
export { DataLegendStylingRowEventArgsDescriptionMetadata };
